pub struct Metadata { /* private fields */ }Expand description
The meta data of a message.
Equivalent to struct orb_metadata in C and C++.
You can obtain a message’s metadata through
Message::metadata().
Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub fn size_no_padding(&self) -> u16
pub fn size_no_padding(&self) -> u16
The size of the message in bytes, without any padding at the end.
Sourcepub fn fields(&self) -> &str
pub fn fields(&self) -> &str
A description of all fields and padding in the message.
See message_format_s in the
ulog file format
for a specification of this string.
Sourcepub fn fields_cstr(&self) -> &CStr
pub fn fields_cstr(&self) -> &CStr
Same as fields, but as zero-terminated C string.